<?php

/**
 * @file
 * Callback for menu link.
 */

/**
 * Implements Callback of admin/management/image_upload.
 */
function s3_zip_image_upload_multiple() {
  $output = '';
  $form = drupal_get_form('s3_zip_image_upload_multiple_form');
  $output .= render($form);
  return $output;
}

/**
 * Implements hook_form().
 */
function s3_zip_image_upload_multiple_form($form, &$form_state) {
  global $base_url;
  $library = libraries_detect('amazon-s3-php-class');
  if (!$library['installed']) {
    if ($library['error'] == 'not found' || $library['error'] == 'not detected') {
      $lib_error_message = strip_tags($library['error message']);
      drupal_set_message(t('@error Please make sure the library is <a href="@installedcorrectly">installed correctly</a>.', array('@error' => $lib_error_message, '@installedcorrectly' => $base_url . '/admin/help/s3_zip_image_upload')), 'error');
      watchdog('amazon-s3-php-class', $library['error message'], NULL, WATCHDOG_ERROR);
      return;
    }
  }
  $form['file_type'] = array(
    '#type' => 'select',
    '#title' => t('File Type'),
    '#options' => array(
      'images' => t('Images'),
    ),
    '#default_value' => 'images',
    '#disabled' => TRUE,
    '#description' => t('Allowed file extensions : jpg,jpeg,png'),
  );
  $form['aws_creds'] = array(
    '#type' => 'fieldset',
    '#title' => t('SHOW AMAZON WEB SERVICES CREDENTIALS'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['aws_creds']['destination_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon S3 path'),
    '#default_value' => "http://" . variable_get('s3fs_bucket') . ".s3.amazonaws.com/s3fs-public",
    '#disabled' => TRUE,
  );
  $form['aws_creds']['bucket_name'] = array(
    '#type' => 'textfield',
    '#title' => t('S3 Bucket Name'),
    '#default_value' => variable_get('s3fs_bucket'),
    '#disabled' => TRUE,
  );
  $form['aws_creds']['access_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon Web Services Access Key'),
    '#default_value' => variable_get('s3fs_awssdk2_access_key'),
    '#disabled' => TRUE,
  );
  $form['aws_creds']['secret_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon Web Services Secret Key'),
    '#default_value' => variable_get('s3fs_awssdk2_secret_key'),
    '#disabled' => TRUE,
  );

  $form['aws_creds']['folder_name'] = array(
    '#type' => 'textfield',
    '#title' => t('S3 folder name'),
    '#description' => t('Name of the folder where images will store on AWS'),
    '#required' => TRUE,
  );
  $form['zip_file'] = array(
    '#type' => 'file',
    '#title' => t('Upload Zip File'),
    '#size' => 48,
    '#description' => t('Warning : MAX SIZE LIMIT : 1GB. !break ZIP File should contain Images directly, not in Folder. !breakAllowed Image Extesion are: JPG, JPEG, PNG'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Upload',
  );
  return $form;
}

/**
 * Implements submit to upload Product and Resized images to S3.
 */
function s3_zip_image_upload_multiple_form_submit($form, &$form_state) {
  $selected_type = $form_state['values']['file_type'];
  $directory_name = $form_state['values']['folder_name'];
  $bucket_name = variable_get('s3fs_bucket');
  $aws_url = "http://$bucket_name.s3.amazonaws.com/s3fs-public";
  $access_key = variable_get('s3fs_awssdk2_access_key');
  $secret_key = variable_get('s3fs_awssdk2_secret_key');
  $file_public_path = variable_get('file_public_path');
  $realpath = realpath("$file_public_path/$directory_name");
  if (is_writable($realpath)) {
    drupal_mkdir("public://$directory_name", 777);
  }
  else {
    drupal_mkdir("public://$directory_name", 777);
  }
  $bDirectoryExists = is_dir("public://$directory_name/");
  if ($bDirectoryExists) {
    $file = file_save_upload('zip_file', array('file_validate_extensions' => array('zip')), 'temporary://', FILE_EXISTS_REPLACE);
    // Zip FIle.
    $zip = new ZipArchive;
    $zip = zip_open(drupal_realpath($file->uri));
    $count = 0;
    $invalid_files = '';
    if (is_resource($zip)) {
      while ($zip_entry = zip_read($zip)) {
        $product_filename = zip_entry_name($zip_entry);
        $product_extension = 'jpg';
        if (!in_array($product_extension, array('jpg', 'JPG', 'jpeg', 'JPEG'))) {
          $count++;
          $invalid_files .= $count . ')' . $product_filename . '<br/>';
        }
      }
      $zip = zip_close($zip);
      // Images Validation in Zip.
      if ($count > 0) {
        $message = t('An error occurred and processing did not complete.!break Please Upload only image files. !break There are %count invalid files as @invalid_files', array(
          '!break' => '<br/>',
          '%count' => $count,
          '@invalid_files' => $invalid_files,
            )
        );
        drupal_set_message($message, 'error');
      }
      else {
        // Zip Extracting.
        $zip = new ZipArchive();
        $zip->open(drupal_realpath($file->uri));
        $zip->extractTo("$file_public_path/$directory_name");
        $zip->close();
      }
      $dir = "$file_public_path/$directory_name/";
      // Scan Product Images directory for all files.
      if ($selected_type == 'images') {
        $files = file_scan_directory($dir, '/^.*\.(jpg|JPG|jpeg|JPEG|png|PNG)$/');
      }
      $images_created = array_chunk($files, 25);
      $highest_row = count($files);
      $count = 0;
      $download_batch = array(
        'title' => t('Uploading Images'),
        'progress_message' => t('Uploading Files to S3...'),
        'error_message' => t('Error!'),
        // Function call on completion of batch process.
        'finished' => 's3_zip_image_upload_data_finish',
      );
      foreach ($images_created as $images) {
        $count = $count + count($images);
        $download_batch['operations'][] = array('s3_zip_image_upload_data',
          array(
            $images,
            $count,
            $highest_row,
            $selected_type,
            $aws_url,
            $directory_name,
            $bucket_name,
            $access_key,
            $secret_key,
          ),
        );
      }
      batch_set($download_batch);
    }
  }
  else {
    form_set_error('folder_name', t('Unable to create directory. Please check public:// permissions'));
  }
}
